@@ -101,9 +101,10 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <stdio.h>
+#ifndef _MSC_VER
 #include <string.h>
 #include <strings.h>
-
+#endif
 #include "udunits2.h"
 
 static ut_unit*		_finalUnit;	/* fully-parsed specification */
@@ -278,7 +279,7 @@ static int isTime(
 
 
 /* Line 268 of yacc.c  */
-#line 282 "parser.c"
+#line 283 "parser.c"
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -327,7 +328,7 @@ typedef union YYSTYPE
 {
 
 /* Line 293 of yacc.c  */
-#line 203 "parser.y"
+#line 204 "parser.y"
 
     char*	id;			/* identifier */
     ut_unit*	unit;			/* "unit" structure */
@@ -337,7 +338,7 @@ typedef union YYSTYPE
 
 
 /* Line 293 of yacc.c  */
-#line 341 "parser.c"
+#line 342 "parser.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -349,7 +350,7 @@ typedef union YYSTYPE
 
 
 /* Line 343 of yacc.c  */
-#line 353 "parser.c"
+#line 354 "parser.c"
 
 #ifdef short
 # undef short
@@ -648,10 +649,10 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   233,   233,   237,   241,   246,   249,   255,   261,   267,
-     275,   279,   287,   293,   301,   307,   315,   323,   326,   332,
-     338,   346,   399,   402,   408,   414,   420,   426,   429,   434,
-     437,   440,   443,   462,   465,   468
+       0,   234,   234,   238,   242,   247,   250,   256,   262,   268,
+     276,   280,   288,   294,   302,   308,   316,   324,   327,   333,
+     339,   347,   400,   403,   409,   415,   421,   427,   430,   435,
+     438,   441,   444,   463,   466,   469
 };
 #endif
 
@@ -1614,7 +1615,7 @@ yyreduce:
         case 2:
 
 /* Line 1806 of yacc.c  */
-#line 233 "parser.y"
+#line 234 "parser.y"
     {
 		    _finalUnit = ut_get_dimensionless_unit_one(_unitSystem);
 		    YYACCEPT;
@@ -1624,7 +1625,7 @@ yyreduce:
   case 3:
 
 /* Line 1806 of yacc.c  */
-#line 237 "parser.y"
+#line 238 "parser.y"
     {
 		    _finalUnit = (yyvsp[(1) - (1)].unit);
 		    YYACCEPT;
@@ -1634,7 +1635,7 @@ yyreduce:
   case 4:
 
 /* Line 1806 of yacc.c  */
-#line 241 "parser.y"
+#line 242 "parser.y"
     {
 		    YYABORT;
 		}
@@ -1643,7 +1644,7 @@ yyreduce:
   case 5:
 
 /* Line 1806 of yacc.c  */
-#line 246 "parser.y"
+#line 247 "parser.y"
     {
 		    (yyval.unit) = (yyvsp[(1) - (1)].unit);
 		}
@@ -1652,7 +1653,7 @@ yyreduce:
   case 6:
 
 /* Line 1806 of yacc.c  */
-#line 249 "parser.y"
+#line 250 "parser.y"
     {
 		    (yyval.unit) = ut_offset((yyvsp[(1) - (3)].unit), (yyvsp[(3) - (3)].rval));
 		    ut_free((yyvsp[(1) - (3)].unit));
@@ -1664,7 +1665,7 @@ yyreduce:
   case 7:
 
 /* Line 1806 of yacc.c  */
-#line 255 "parser.y"
+#line 256 "parser.y"
     {
 		    (yyval.unit) = ut_offset((yyvsp[(1) - (3)].unit), (yyvsp[(3) - (3)].ival));
 		    ut_free((yyvsp[(1) - (3)].unit));
@@ -1676,7 +1677,7 @@ yyreduce:
   case 8:
 
 /* Line 1806 of yacc.c  */
-#line 261 "parser.y"
+#line 262 "parser.y"
     {
 		    (yyval.unit) = ut_offset_by_time((yyvsp[(1) - (3)].unit), (yyvsp[(3) - (3)].rval));
 		    ut_free((yyvsp[(1) - (3)].unit));
@@ -1688,7 +1689,7 @@ yyreduce:
   case 9:
 
 /* Line 1806 of yacc.c  */
-#line 267 "parser.y"
+#line 268 "parser.y"
     {
 		    ut_status	prev = ut_get_status();
 		    ut_free((yyvsp[(1) - (3)].unit));
@@ -1700,7 +1701,7 @@ yyreduce:
   case 10:
 
 /* Line 1806 of yacc.c  */
-#line 275 "parser.y"
+#line 276 "parser.y"
     {
 		    (yyval.unit) = (yyvsp[(1) - (1)].unit);
                     _isTime = isTime((yyval.unit));
@@ -1710,7 +1711,7 @@ yyreduce:
   case 11:
 
 /* Line 1806 of yacc.c  */
-#line 279 "parser.y"
+#line 280 "parser.y"
     {
 		    (yyval.unit) = ut_multiply((yyvsp[(1) - (2)].unit), (yyvsp[(2) - (2)].unit));
                     _isTime = isTime((yyval.unit));
@@ -1724,7 +1725,7 @@ yyreduce:
   case 12:
 
 /* Line 1806 of yacc.c  */
-#line 287 "parser.y"
+#line 288 "parser.y"
     {
 		    ut_status	prev = ut_get_status();
 		    ut_free((yyvsp[(1) - (2)].unit));
@@ -1736,7 +1737,7 @@ yyreduce:
   case 13:
 
 /* Line 1806 of yacc.c  */
-#line 293 "parser.y"
+#line 294 "parser.y"
     {
 		    (yyval.unit) = ut_multiply((yyvsp[(1) - (3)].unit), (yyvsp[(3) - (3)].unit));
                     _isTime = isTime((yyval.unit));
@@ -1750,7 +1751,7 @@ yyreduce:
   case 14:
 
 /* Line 1806 of yacc.c  */
-#line 301 "parser.y"
+#line 302 "parser.y"
     {
 		    ut_status	prev = ut_get_status();
 		    ut_free((yyvsp[(1) - (3)].unit));
@@ -1762,7 +1763,7 @@ yyreduce:
   case 15:
 
 /* Line 1806 of yacc.c  */
-#line 307 "parser.y"
+#line 308 "parser.y"
     {
 		    (yyval.unit) = ut_divide((yyvsp[(1) - (3)].unit), (yyvsp[(3) - (3)].unit));
                     _isTime = isTime((yyval.unit));
@@ -1776,7 +1777,7 @@ yyreduce:
   case 16:
 
 /* Line 1806 of yacc.c  */
-#line 315 "parser.y"
+#line 316 "parser.y"
     {
 		    ut_status	prev = ut_get_status();
 		    ut_free((yyvsp[(1) - (3)].unit));
@@ -1788,7 +1789,7 @@ yyreduce:
   case 17:
 
 /* Line 1806 of yacc.c  */
-#line 323 "parser.y"
+#line 324 "parser.y"
     {
 		    (yyval.unit) = (yyvsp[(1) - (1)].unit);
 		}
@@ -1797,7 +1798,7 @@ yyreduce:
   case 18:
 
 /* Line 1806 of yacc.c  */
-#line 326 "parser.y"
+#line 327 "parser.y"
     {
 		    (yyval.unit) = ut_raise((yyvsp[(1) - (2)].unit), (yyvsp[(2) - (2)].ival));
 		    ut_free((yyvsp[(1) - (2)].unit));
@@ -1809,7 +1810,7 @@ yyreduce:
   case 19:
 
 /* Line 1806 of yacc.c  */
-#line 332 "parser.y"
+#line 333 "parser.y"
     {
 		    (yyval.unit) = ut_raise((yyvsp[(1) - (2)].unit), (yyvsp[(2) - (2)].ival));
 		    ut_free((yyvsp[(1) - (2)].unit));
@@ -1821,7 +1822,7 @@ yyreduce:
   case 20:
 
 /* Line 1806 of yacc.c  */
-#line 338 "parser.y"
+#line 339 "parser.y"
     {
 		    ut_status	prev = ut_get_status();
 		    ut_free((yyvsp[(1) - (2)].unit));
@@ -1833,7 +1834,7 @@ yyreduce:
   case 21:
 
 /* Line 1806 of yacc.c  */
-#line 346 "parser.y"
+#line 347 "parser.y"
     {
 		    double	prefix = 1;
 		    ut_unit*	unit = NULL;
@@ -1892,7 +1893,7 @@ yyreduce:
   case 22:
 
 /* Line 1806 of yacc.c  */
-#line 399 "parser.y"
+#line 400 "parser.y"
     {
 		    (yyval.unit) = (yyvsp[(2) - (3)].unit);
 		}
@@ -1901,7 +1902,7 @@ yyreduce:
   case 23:
 
 /* Line 1806 of yacc.c  */
-#line 402 "parser.y"
+#line 403 "parser.y"
     {
 		    ut_status	status = ut_get_status();
 		    ut_free((yyvsp[(2) - (3)].unit));
@@ -1913,7 +1914,7 @@ yyreduce:
   case 24:
 
 /* Line 1806 of yacc.c  */
-#line 408 "parser.y"
+#line 409 "parser.y"
     {
 		    (yyval.unit) = ut_log((yyvsp[(1) - (3)].rval), (yyvsp[(2) - (3)].unit));
 		    ut_free((yyvsp[(2) - (3)].unit));
@@ -1925,7 +1926,7 @@ yyreduce:
   case 25:
 
 /* Line 1806 of yacc.c  */
-#line 414 "parser.y"
+#line 415 "parser.y"
     {
 		    ut_status	status = ut_get_status();
 		    ut_free((yyvsp[(2) - (3)].unit));
@@ -1937,7 +1938,7 @@ yyreduce:
   case 26:
 
 /* Line 1806 of yacc.c  */
-#line 420 "parser.y"
+#line 421 "parser.y"
     {
 		    (yyval.unit) = ut_scale((yyvsp[(1) - (1)].rval),
                         ut_get_dimensionless_unit_one(_unitSystem));
@@ -1947,7 +1948,7 @@ yyreduce:
   case 27:
 
 /* Line 1806 of yacc.c  */
-#line 426 "parser.y"
+#line 427 "parser.y"
     {
 		    (yyval.rval) = (yyvsp[(1) - (1)].ival);
 		}
@@ -1956,7 +1957,7 @@ yyreduce:
   case 28:
 
 /* Line 1806 of yacc.c  */
-#line 429 "parser.y"
+#line 430 "parser.y"
     {
 		    (yyval.rval) = (yyvsp[(1) - (1)].rval);
 		}
@@ -1965,7 +1966,7 @@ yyreduce:
   case 29:
 
 /* Line 1806 of yacc.c  */
-#line 434 "parser.y"
+#line 435 "parser.y"
     {
 		    (yyval.rval) = (yyvsp[(1) - (1)].rval);
 		}
@@ -1974,7 +1975,7 @@ yyreduce:
   case 30:
 
 /* Line 1806 of yacc.c  */
-#line 437 "parser.y"
+#line 438 "parser.y"
     {
 		    (yyval.rval) = (yyvsp[(1) - (2)].rval) + (yyvsp[(2) - (2)].rval);
 		}
@@ -1983,7 +1984,7 @@ yyreduce:
   case 31:
 
 /* Line 1806 of yacc.c  */
-#line 440 "parser.y"
+#line 441 "parser.y"
     {
 		    (yyval.rval) = (yyvsp[(1) - (3)].rval) + ((yyvsp[(2) - (3)].rval) - (yyvsp[(3) - (3)].rval));
 		}
@@ -1992,7 +1993,7 @@ yyreduce:
   case 32:
 
 /* Line 1806 of yacc.c  */
-#line 443 "parser.y"
+#line 444 "parser.y"
     {
 		    int	error = 0;
 
@@ -2017,7 +2018,7 @@ yyreduce:
   case 33:
 
 /* Line 1806 of yacc.c  */
-#line 462 "parser.y"
+#line 463 "parser.y"
     {
 		    (yyval.rval) = (yyvsp[(1) - (1)].rval);
 		}
@@ -2026,7 +2027,7 @@ yyreduce:
   case 34:
 
 /* Line 1806 of yacc.c  */
-#line 465 "parser.y"
+#line 466 "parser.y"
     {
 		    (yyval.rval) = (yyvsp[(1) - (2)].rval) - (yyvsp[(2) - (2)].rval);
 		}
@@ -2035,7 +2036,7 @@ yyreduce:
   case 35:
 
 /* Line 1806 of yacc.c  */
-#line 468 "parser.y"
+#line 469 "parser.y"
     {
 		    int	error = 0;
 
@@ -2060,7 +2061,7 @@ yyreduce:
 
 
 /* Line 1806 of yacc.c  */
-#line 2064 "parser.c"
+#line 2065 "parser.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2291,7 +2292,7 @@ yyreturn:
 
 
 /* Line 2067 of yacc.c  */
-#line 489 "parser.y"
+#line 490 "parser.y"
 
 
 #define yymaxdepth	utmaxdepth
@@ -2369,30 +2370,27 @@ latin1ToUtf8(
         else {
             ut_handle_error_message("Couldn't allocate %ld-byte buffer: %s",
                 (unsigned long)size, strerror(errno));
-
             return NULL;
         }
     }
 
-    for (in = (const unsigned char*)latin1String,
-            out = (unsigned char*)utf8String; *in; ++in) {
-#       define IS_ASCII(c) (((c) & 0x80) == 0)
+    if (utf8String) {
+        for (in = (const unsigned char*)latin1String,
+                out = (unsigned char*)utf8String; *in; ++in) {
+#           define IS_ASCII(c) (((c) & 0x80) == 0)
 
-        if((unsigned char*)utf8String == NULL)
-            break;
+            if (IS_ASCII(*in)) {
+                *out++ = *in;
+            }
+            else {
+                *out++ = 0xC0 | ((0xC0 & *in) >> 6);
+                *out++ = 0x80 | (0x3F & *in);
+            }
+        }
 
-        if (IS_ASCII(*in)) {
-            *out++ = *in;
-        }
-        else {
-            *out++ = 0xC0 | ((0xC0 & *in) >> 6);
-            *out++ = 0x80 | (0x3F & *in);
-        }
+        *out = 0;
     }
 
-    if(out)
-      *out = 0;
-
     return utf8String;
 }
 
