@@ -1799,6 +1799,32 @@ test_parsing(void)
     CU_ASSERT_EQUAL(ut_compare(unit, kilometer), 0);
     ut_free(unit);
 
+    spec = "1/2";
+    unit = ut_parse(unitSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit);
+    CU_ASSERT_EQUAL(ut_are_convertible(unit,
+            ut_get_dimensionless_unit_one(unitSystem)), 1);
+    ut_free(unit);
+
+    spec = "1/(2)";
+    unit = ut_parse(unitSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit);
+    CU_ASSERT_EQUAL(ut_are_convertible(unit,
+            ut_get_dimensionless_unit_one(unitSystem)), 1);
+    ut_free(unit);
+
+    spec = "1/m";
+    unit = ut_parse(unitSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit);
+    CU_ASSERT_EQUAL(ut_are_convertible(unit, meter), 1);
+    ut_free(unit);
+
+    spec = "1/(2 m)";
+    unit = ut_parse(unitSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit);
+    CU_ASSERT_EQUAL(ut_are_convertible(unit, meter), 1);
+    ut_free(unit);
+
     spec = "(K/1.8) @ 459.67";
     unit = ut_parse(unitSystem, spec, UT_ASCII);
     CU_ASSERT_EQUAL(ut_are_convertible(unit, fahrenheit), 1);
@@ -1876,6 +1902,12 @@ test_parsing(void)
     CU_ASSERT_EQUAL(ut_compare(unit, secondsSinceTheEpoch), 0);
     ut_free(unit);
 
+    spec = "second ref 1970-01-01T00:00:00Z";
+    unit = ut_parse(unitSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit);
+    CU_ASSERT_EQUAL(ut_compare(unit, secondsSinceTheEpoch), 0);
+    ut_free(unit);
+
     spec = "kg\xb7m\xb2/s\xb3"; /* "kg" mid-dot "m" squared "/" "s" cubed */
     unit = ut_parse(unitSystem, spec, UT_LATIN1);
     CU_ASSERT_PTR_NOT_NULL(unit);
